==> haskell-toml-parser-2.0.1.2-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.1.2
visibility:           public
id:                   toml-parser-2.0.1.2-1axDXlnfuV68ndpfoPDoB
key:                  toml-parser-2.0.1.2-1axDXlnfuV68ndpfoPDoB
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  f7e7a64ef5eac7fa189ba052decdb45f
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.1.2-1axDXlnfuV68ndpfoPDoB
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    prettyprinter-1.7.1-CmtY07bno6e3Q2mVZUKdcs text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-toml-parser-2.0.1.2-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-toml-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 toml-parser
version:              2.0.1.2
visibility:           public
id:                   toml-parser-2.0.1.2-5LZNFLUrofmGEYPU8Q1cOH
key:                  toml-parser-2.0.1.2-5LZNFLUrofmGEYPU8Q1cOH
license:              ISC
copyright:            2023 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
synopsis:             TOML 1.0.0 parser
description:
    TOML parser using generated lexers and parsers with
    careful attention to the TOML 1.0.0 semantics for
    defining tables.

category:             Text
abi:                  adf568d2c3de52237293829b90a70b54
exposed:              True
exposed-modules:
    Toml Toml.Pretty Toml.Schema Toml.Schema.FromValue
    Toml.Schema.Generic Toml.Schema.Generic.FromValue
    Toml.Schema.Generic.ToValue Toml.Schema.Matcher
    Toml.Schema.ParseTable Toml.Schema.ToValue Toml.Semantics
    Toml.Semantics.Ordered Toml.Semantics.Types Toml.Syntax
    Toml.Syntax.Lexer Toml.Syntax.Parser Toml.Syntax.Position
    Toml.Syntax.Token Toml.Syntax.Types

hidden-modules:       Toml.Syntax.LexerUtils Toml.Syntax.ParserUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/toml-parser-2.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-toml-parser
hs-libraries:         HStoml-parser-2.0.1.2-5LZNFLUrofmGEYPU8Q1cOH
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    prettyprinter-1.7.1-H1CnA9YdkYYkwP4aBwQ7e text-2.0.2 time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-toml-parser/html/toml-parser.haddock
haddock-html:         /usr/share/doc/haskell-toml-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
